@@ -76,6 +76,7 @@ def _get_numerai_fetcher(filename_float32, filename_int8, name, has_rounds=False
         *,
         data_home=None,
         download_if_missing=True,
+        keep=False,
         return_X_y=False,
         target="target",
         as_frame=False,
@@ -119,7 +120,8 @@ def _get_numerai_fetcher(filename_float32, filename_int8, name, has_rounds=False
             napi.download_dataset(filename, dest_path=filepath)
 
             df = pd.read_parquet(filepath, columns=columns)
-            remove(filepath)
+            if not keep:
+                remove(filepath)
         else:
             df = pd.read_parquet(filepath, columns=columns)
 
@@ -177,13 +179,17 @@ def fetch_numerai_training(*args, **kwargs):
     Parameters
     ----------
     data_home : str, default=None
-        Specify another download and cache folder for the datasets. By default
-        all data is stored in `~/scikit_learn_data` subfolders.
+        Specify another download and cache folder for the datasets. By
+        default all data is stored in `~/scikit_learn_data` subfolders.
 
     download_if_missing : bool, default=True
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
@@ -253,8 +259,8 @@ def fetch_numerai_training(*args, **kwargs):
             `era`, `data_type`, features and targets.
 
         (data, target) : tuple if `return_X_y=True`
-            Only present when `return_X_y=True`
-            `target` corresponds to the column set by the `target` attribute.
+            Only present when `return_X_y=True`. `target` corresponds
+            to the column set by the `target` attribute.
     """
     fetcher = _get_numerai_fetcher(
         "numerai_training_data.parquet",
@@ -270,13 +276,17 @@ def fetch_numerai_test(*args, **kwargs):
     Parameters
     ----------
     data_home : str, default=None
-        Specify another download and cache folder for the datasets. By default
-        all data is stored in `~/scikit_learn_data` subfolders.
+        Specify another download and cache folder for the datasets. By
+        default all data is stored in `~/scikit_learn_data` subfolders.
 
     download_if_missing : bool, default=True
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
@@ -346,8 +356,8 @@ def fetch_numerai_test(*args, **kwargs):
             `era`, `data_type`, features and targets.
 
         (data, target) : tuple if `return_X_y=True`
-            Only present when `return_X_y=True`
-            `target` corresponds to the column set by the `target` attribute.
+            Only present when `return_X_y=True`. `target` corresponds
+            to the column set by the `target` attribute.
     """
     fetcher = _get_numerai_fetcher(
         "numerai_test_data.parquet",
@@ -370,6 +380,10 @@ def fetch_numerai_validation(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
@@ -439,9 +453,8 @@ def fetch_numerai_validation(*args, **kwargs):
             `era`, `data_type`, features and targets.
 
         (data, target) : tuple if `return_X_y=True`
-            Only present when `return_X_y=True`
-            `target` corresponds to the column set by the `target`
-            attribute.
+            Only present when `return_X_y=True`. `target` corresponds
+            to the column set by the `target` attribute.
     """
     fetcher = _get_numerai_fetcher(
         "numerai_validation_data.parquet",
@@ -464,6 +477,10 @@ def fetch_numerai_live(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
@@ -537,9 +554,8 @@ def fetch_numerai_live(*args, **kwargs):
             `era`, `data_type`, features and targets.
 
         (data, target) : tuple if `return_X_y=True`
-            Only present when `return_X_y=True`
-            `target` corresponds to the column set by the `target`
-            attribute.
+            Only present when `return_X_y=True`. `target` corresponds
+            to the column set by the `target` attribute.
 
     Notes
     -----
@@ -567,6 +583,10 @@ def fetch_numerai_tournament(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
@@ -640,9 +660,8 @@ def fetch_numerai_tournament(*args, **kwargs):
             `era`, `data_type`, features and targets.
 
         (data, target) : tuple if `return_X_y=True`
-            Only present when `return_X_y=True`
-            `target` corresponds to the column set by the `target`
-            attribute.
+            Only present when `return_X_y=True`. `target` corresponds
+            to the column set by the `target` attribute.
 
     Notes
     -----
@@ -736,6 +755,10 @@ def fetch_numerai_example_predictions(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_y : bool, default=False.
         If True, returns `prediction` instead of a Bunch object.
 
@@ -792,6 +815,10 @@ def fetch_numerai_example_validation_predictions(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     return_y : bool, default=False.
         If True, returns `prediction` instead of a Bunch object.
 
@@ -826,7 +853,9 @@ def fetch_numerai_example_validation_predictions(*args, **kwargs):
     return fetcher(*args, **kwargs)
 
 
-def fetch_numerai_feature_metadata(*, data_home=None, download_if_missing=True):
+def fetch_numerai_feature_metadata(
+    *, data_home=None, download_if_missing=True, keep=False
+):
     """Load the Numerai feature metadata.
 
     Parameters
@@ -840,6 +869,10 @@ def fetch_numerai_feature_metadata(*, data_home=None, download_if_missing=True):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
+    keep : bool, default=False
+        If True, does not remove the downloaded file from disk after
+        reading it.
+
     Returns
     -------
     feature_metadata : dict
@@ -875,7 +908,8 @@ def fetch_numerai_feature_metadata(*, data_home=None, download_if_missing=True):
         napi.download_dataset(filename, dest_path=filepath)
 
         feature_metadata_dict = _read_json_file(filepath)
-        remove(filepath)
+        if not keep:
+            remove(filepath)
     else:
         feature_metadata_dict = _read_json_file(filepath)
 
